import { env } from "#root/env.js";
import { resolve } from "node:path";
import pino, { LoggerOptions, TransportTargetOptions } from "pino";

function createLoggerInstance() {
	const transportTargets: TransportTargetOptions[] = [];

	let consoleTarget: TransportTargetOptions = {
		target: "pino-pretty",
		level: env.LOG_LEVEL,
		options: {
			colorize: true,
			ignore: "pid,hostname",
			translateTime: "SYS:dd.mm.yyyy, HH:MM:ss",
		},
	};

	transportTargets.push(consoleTarget);

	let fileTarget: TransportTargetOptions = {
		target: "pino-roll",
		level: env.LOG_LEVEL,
		options: {
			file: resolve("logs", "app"),
			extension: ".log",
			frequency: "daily",
			size: "10m",
			limit: {
				count: 10,
			},
			mkdir: true,
		},
	};

	if (env.LOG_FILE) transportTargets.push(fileTarget);

	const options: LoggerOptions = {
		level: env.LOG_LEVEL,
	};

	const transport = pino.transport({
		targets: transportTargets,
	});

	const logger = pino(options, transport);

	return logger;
}

export const logger = createLoggerInstance();
